@@ -1,4 +1,4 @@
-all_packages = [
+all_package_extensions = [
 	"bot_settings",
 	"command_event",
 	"connect_event",
