@@ -1,4 +1,4 @@
-from .. import utils
+import botutils as utils
 from discord.ext import commands
 import discord
 
